Compositor

Struct Compositor 

pub struct Compositor { /* private fields */ }
Fundamentally, the compositor works on a massive set of pre-allocated vertices that it assembles into quads in the vertex shader, which then moves them into position and assigns them UV coordinates. Then the pixel shader checks if it must do per-pixel clipping and discards the pixel if it’s out of bounds, then samples a texture from the provided texture bank, does color modulation if applicable, then draws the final pixel to the screen using pre-multiplied alpha blending. This allows the compositor to avoid allocating a vertex buffer, instead using a SSBO (or webgpu storage buffer) to store the per-quad data, which it then accesses from the built-in vertex index.

The compositor can accept GPU generated instructions written directly into it’s buffer using a compute shader, if desired.

The compositor can also accept custom draw calls that break up the batched compositor instructions, which is intended for situations where rendering to the texture atlas is either impractical, or a different blending operation is required (such as subpixel blended text, which requires the SRC1 dual-source blending mode, instead of standard pre-multiplied alpha).

Implementations

Source

impl Compositor

pub fn new( device: &Device, shared: &Shared, atlasview: &Arc<TextureView>, layerview: &Arc<TextureView>, format: TextureFormat, layer: bool, ) -> Self

pub fn prepare( &mut self, driver: &Driver, _: &mut CommandEncoder, surface_dim: PxDim, )

pub fn draw( &mut self, driver: &Driver, pass: &mut RenderPass<'_>, index: u8, slice: u8, )

pub fn cleanup(&mut self)