pub struct Placement {
pub left: i32,
pub top: i32,
pub width: u32,
pub height: u32,
}Expand description
Describes the offset and dimensions of a rendered mask.
Fields
left: i32Horizontal offset with respect to the origin specified when computing the placement.
top: i32Vertical offset with respect to the origin specified when computing the placement.
width: u32Width in pixels.
height: u32Height in pixels.
Implementations