pub struct ImageRef(pub Arc<DynamicImage>);Tuple Fields
0: Arc<DynamicImage>Trait Implementations
Sourceimpl Hash for ImageRef
Available on crate features avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.
impl Hash for ImageRef
Available on crate features
avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.Sourceimpl Location for ImageRef
Available on crate features avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.
impl Location for ImageRef
Available on crate features
avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.Sourceimpl PartialEq for ImageRef
Available on crate features avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.
impl PartialEq for ImageRef
Available on crate features
avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.impl Eq for ImageRef
Available on crate features
avif or bmp or dds or exr or ff or gif or hdr or ico or pnm or qoi or tga or tiff or webp only.Auto Trait Implementations
impl Freeze for ImageRef
impl RefUnwindSafe for ImageRef
impl Send for ImageRef
impl Sync for ImageRef
impl Unpin for ImageRef
impl UnwindSafe for ImageRef